@@ -1,6 +1,7 @@
 
 ## BART: Bayesian Additive Regression Trees
 ## Copyright (C) 2017-2018 Robert McCulloch and Rodney Sparapani
+## mc.pwbart
 
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -41,12 +42,13 @@ mc.pwbart = function(
     if(!is.na(mc.cores.detected) && mc.cores>mc.cores.detected) mc.cores <- mc.cores.detected
 
     K <- ncol(x.test)
+    if(K<mc.cores) mc.cores=K
     k <- K%/%mc.cores-1
     j <- K
     for(i in 1:mc.cores) {
         if(i==mc.cores) h <- 1
         else h <- j-k
-
+        ##print(c(i=i, h=h, j=j))
         parallel::mcparallel({psnice(value=nice);
             pwbart(matrix(x.test[ , h:j], nrow=p, ncol=j-h+1), treedraws, mu, 1, TRUE)},
             silent=(i!=1))
@@ -68,11 +70,19 @@ mc.pwbart = function(
     ## }
 
     pred.list <- parallel::mccollect()
-
     pred <- pred.list[[1]]
+    type=class(pred)[1]
+    if(type=='list') pred <- pred[[1]]
+    else if(type!='matrix') return(pred.list) ## likely error messages
 
-    if(mc.cores>1) for(i in 2:mc.cores) pred <- cbind(pred, pred.list[[i]])
+    if(mc.cores>1) for(i in 2:mc.cores) {
+            if(type=='list') pred <- cbind(pred, pred.list[[i]][[1]])
+            else pred <- cbind(pred, pred.list[[i]])
+        }
+    ##if(mc.cores>1) for(i in 2:mc.cores) pred <- cbind(pred, pred.list[[i]])
 
-    if(dodraws) return(pred+mu)
-    else return(apply(pred, 2, mean)+mu)
+    if(dodraws) return(pred)
+    else return(apply(pred, 2, mean))
+    ## if(dodraws) return(pred+mu)
+    ## else return(apply(pred, 2, mean)+mu)
 }
